@@ -7,13 +7,18 @@ class Mechanize::ResponseCodeError < Mechanize::Error
   attr_reader :response_code
   attr_reader :page
 
-  def initialize(page)
+  def initialize(page, message = nil)
+    super message
+
     @page          = page
     @response_code = page.code.to_s
   end
 
   def to_s
-    "#{@response_code} => #{Net::HTTPResponse::CODE_TO_OBJ[@response_code]}"
+    response_class = Net::HTTPResponse::CODE_TO_OBJ[@response_code]
+    out = "#{@response_code} => #{response_class} "
+    out << "for #{@page.uri} " if @page.respond_to? :uri # may be HTTPResponse
+    out << "-- #{super}"
   end
 
   alias inspect to_s
