@@ -5,7 +5,7 @@ class TestMechanizeFileResponse < Mechanize::TestCase
   def test_content_type
     Tempfile.open %w[pi .nothtml] do |tempfile|
       res = Mechanize::FileResponse.new tempfile.path
-      assert_equal nil, res['content-type']
+      assert_nil res['content-type']
     end
 
     Tempfile.open %w[pi .xhtml] do |tempfile|
