@@ -214,7 +214,7 @@ class TestMechanizeForm < Mechanize::TestCase
 
     @form['name'] = 'Aaron'
 
-    assert @form.has_field?('name')
+    assert_equal true, @form.has_field?('name')
   end
 
   def test_has_value_eh
@@ -222,7 +222,7 @@ class TestMechanizeForm < Mechanize::TestCase
 
     @form['name'] = 'Aaron'
 
-    assert @form.has_value?('Aaron')
+    assert_equal true, @form.has_value?('Aaron')
   end
 
   def test_keys
@@ -863,15 +863,19 @@ class TestMechanizeForm < Mechanize::TestCase
   def test_form_and_fields_dom_id
     # blatant copypasta of test above
     page = @mech.get("http://localhost/form_test.html")
-    form = page.form_with(:dom_id => 'generic_form')
-    form_by_id = page.form_with(:id => 'generic_form')
+    form = page.form_with(dom_id: 'generic_form')
 
-    assert_equal(1, form.fields_with(:dom_id => 'name_first').length)
-    assert_equal('first_name', form.field_with(:dom_id => 'name_first').name)
+    assert_equal(1, form.fields_with(dom_id: 'name_first').length)
+    assert_equal('first_name', form.field_with(dom_id: 'name_first').name)
 
-    #  *_with(:id => blah) should work exactly like (:dom_id => blah)
-    assert_equal(form, form_by_id)
-    assert_equal(form.fields_with(:dom_id => 'name_first'), form.fields_with(:id => 'name_first'))
+    assert_equal(form, page.form_with(id: 'generic_form'))
+    assert_equal(form, page.form_with(css: '#generic_form'))
+
+    fields_by_dom_id = form.fields_with(dom_id: 'name_first')
+    assert_equal(fields_by_dom_id, form.fields_with(id: 'name_first'))
+    assert_equal(fields_by_dom_id, form.fields_with(css: '#name_first'))
+    assert_equal(fields_by_dom_id, form.fields_with(xpath: '//*[@id="name_first"]'))
+    assert_equal(fields_by_dom_id, form.fields_with(search: '//*[@id="name_first"]'))
   end
 
   def test_form_and_fields_dom_class
@@ -914,9 +918,9 @@ class TestMechanizeForm < Mechanize::TestCase
     page = @mech.get("http://localhost/form_multival.html")
     form = page.form_with(:name => 'post_form')
 
-    assert(!form.has_field?('intarweb'))
+    assert_equal false, form.has_field?('intarweb')
     assert form.add_field!('intarweb')
-    assert(form.has_field?('intarweb'))
+    assert_equal true, form.has_field?('intarweb')
   end
 
   def test_fill_unexisting_form
